==> _private_chat-0.0.5.tar.gz: lib/chat_list/widget/widget_conversation_item.dart <==
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:_private_chat/chat_detail/message.dart';
import 'package:_private_core/_private_core.dart';
import 'package:_private_core/widgets/widgets.dart';

import 'package:_private_chat/_private_chat.dart';

import 'package:timeago/timeago.dart' as timeago;

class WidgetConversationItem extends StatelessWidget {
  final ChatListConversation m;
  const WidgetConversationItem({
    Key? key,
    required this.m,
  }) : super(key: key);

  TextStyle get styleName => robotoMedium.copyWith(fontSize: 14);
  TextStyle get styleMessage =>
      robotoRegular.copyWith(fontSize: 12, color: hexColor('#99A4AC'));
  TextStyle get styleTime => robotoMedium.copyWith(fontSize: 10);

  int get unread => m.unread;
  String get fullname {
    switch (m.conversationType) {
      case ChatConversationType.solo:
        Map? user = Get.find<ChatListBloc>()
            .state
            .usersByKeys[m.userIds.first[DB_KEY_FIREBASE_ID]];
        return chatGetFullNameUser(user);

      case ChatConversationType.group:
        return m.data[DB_KEY_GROUP_NAME] ?? '';
    }
  }

  String get firebaseId {
    switch (m.conversationType) {
      case ChatConversationType.solo:
        Map? user = Get.find<ChatListBloc>()
            .state
            .usersByKeys[m.userIds.first[DB_KEY_FIREBASE_ID]];
        return chatGetFirebaseIdUser(user);

      case ChatConversationType.group:
        return '';
    }
  }

  String get thumbnail {
    switch (m.conversationType) {
      case ChatConversationType.solo:
        Map? user = Get.find<ChatListBloc>()
            .state
            .usersByKeys[m.userIds.first[DB_KEY_FIREBASE_ID]];
        return chatGetThumbnailUser(user);

      case ChatConversationType.group:
        return m.data[DB_KEY_THUMBNAIL] ?? '';
    }
  }

  String get msg {
    String _ = m.lastMessage[DB_KEY_CONTENT] ?? 'groupcreated'.tr;
    if (m.lastMessage[DB_KEY_MESSAGE_TYPE] ==
        MessageType.homelido_appointment.index) {
      _ = 'invitation'.tr;
    } else if (m.lastMessage[DB_KEY_CONTENT_URL] != null) {
      _ = 'attach'.tr;
    }
    return _;
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      margin: const EdgeInsets.symmetric(vertical: 4),
      padding: const EdgeInsets.symmetric(horizontal: 16, vertical: 12),
      decoration: (unread > 0)
          ? BoxDecoration(color: hexColor('#1F2026'))
          : const BoxDecoration(),
      child: InkWell(
        onTap: () {
          Get.find<ChatListBloc>().add(ChatListReadItemEvent(c: m));
        },
        child: Row(
          mainAxisSize: MainAxisSize.max,
          crossAxisAlignment: CrossAxisAlignment.center,
          mainAxisAlignment: MainAxisAlignment.start,
          children: [
            Hero(
              tag: m.conversationId,
              child: WidgetAppImage(
                imageUrl: thumbnail,
                width: 26 * 2,
                height: 26 * 2,
                radius: 26 * 2,
                errorWidget: CircleAvatar(
                    backgroundImage: AssetImage(assetjpg('defaultavatar'),
                        package: '_private_core')),
              ),
            ),
            const SizedBox(
              width: 15,
            ),
            Flexible(
              fit: FlexFit.tight,
              child: Column(
                mainAxisAlignment: MainAxisAlignment.start,
                crossAxisAlignment: CrossAxisAlignment.start,
                mainAxisSize: MainAxisSize.min,
                children: [
                  Row(
                    children: [
                      Flexible(
                        fit: FlexFit.tight,
                        child: Text(
                          fullname,
                          maxLines: 1,
                          overflow: TextOverflow.ellipsis,
                          style: styleName,
                        ),
                      ),
                      const SizedBox(
                        height: 4,
                      ),
                      Text(
                        timeago.format(
                          DateTime.fromMillisecondsSinceEpoch(
                              m.lastMessage[DB_KEY_TIMESTAMP] ??
                                  m.data[DB_KEY_LAST_MESSAGE_TIME]),
                        ),
                        style: styleTime,
                      )
                    ],
                  ),
                  const SizedBox(
                    height: 6,
                  ),
                  Row(
                    children: [
                      Expanded(
                        child: !kIsWeb &&
                                appPrefs
                                    .getDraftMessage(m.conversationId)
                                    .trim()
                                    .isNotEmpty
                            ? Text(
                                'draft'.tr,
                                maxLines: 2,
                                overflow: TextOverflow.ellipsis,
                                style: styleMessage.copyWith(color: mainColor),
                              )
                            : Text(
                                msg,
                                maxLines: 2,
                                overflow: TextOverflow.ellipsis,
                                style: styleMessage,
                              ),
                      ),
                      if (unread > 0)
                        CircleAvatar(
                          backgroundColor: hexColor('#3E61F7'),
                          radius: 7,
                          child: Padding(
                            padding: const EdgeInsets.all(2.0),
                            child: FittedBox(
                              child: Text(
                                '$unread',
                                style: robotoBold.copyWith(color: Colors.white),
                              ),
                            ),
                          ),
                        )
                    ],
                  )
                ],
              ),
            ),
          ],
        ),
      ),
    );
  }
}

==> _private_chat-0.0.12.tar.gz: lib/chat_list/widget/widget_conversation_item.dart <==
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:_private_chat/chat_detail/message.dart';
import 'package:_private_core/_private_core.dart';
import 'package:_private_core/widgets/widgets.dart';

import 'package:_private_chat/_private_chat.dart';

import 'package:timeago/timeago.dart' as timeago;

class WidgetConversationItem extends StatelessWidget {
  final ChatListConversation m;
  const WidgetConversationItem({
    Key? key,
    required this.m,
  }) : super(key: key);

  TextStyle get styleName => w500TextStyle().copyWith(fontSize: 14);
  TextStyle get styleMessage =>
      w300TextStyle().copyWith(fontSize: 12, color: hexColor('#99A4AC'));
  TextStyle get styleTime => w500TextStyle().copyWith(fontSize: 10);

  int get unread => m.unread;
  String get fullname {
    switch (m.conversationType) {
      case ChatConversationType.solo:
        Map? user = Get.find<ChatListBloc>()
            .state
            .usersByKeys[m.userIds.first[DB_KEY_FIREBASE_ID]];
        return chatGetFullNameUser(user);

      case ChatConversationType.group:
        return m.data[DB_KEY_GROUP_NAME] ?? '';
    }
  }

  String get firebaseId {
    switch (m.conversationType) {
      case ChatConversationType.solo:
        Map? user = Get.find<ChatListBloc>()
            .state
            .usersByKeys[m.userIds.first[DB_KEY_FIREBASE_ID]];
        return chatGetFirebaseIdUser(user);

      case ChatConversationType.group:
        return '';
    }
  }

  String get thumbnail {
    switch (m.conversationType) {
      case ChatConversationType.solo:
        Map? user = Get.find<ChatListBloc>()
            .state
            .usersByKeys[m.userIds.first[DB_KEY_FIREBASE_ID]];
        return chatGetThumbnailUser(user);

      case ChatConversationType.group:
        return m.data[DB_KEY_THUMBNAIL] ?? '';
    }
  }

  String get msg {
    String _ = m.lastMessage[DB_KEY_CONTENT] ?? 'groupcreated'.tr;
    if (m.lastMessage[DB_KEY_MESSAGE_TYPE] ==
        MessageType.homelido_appointment.index) {
      _ = 'invitation'.tr;
    } else if (m.lastMessage[DB_KEY_CONTENT_URL] != null) {
      _ = 'attach'.tr;
    }
    return _;
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      margin: const EdgeInsets.symmetric(vertical: 4),
      padding: const EdgeInsets.symmetric(horizontal: 16, vertical: 12),
      decoration: (unread > 0)
          ? BoxDecoration(color: hexColor('#1F2026'))
          : const BoxDecoration(),
      child: InkWell(
        onTap: () {
          Get.find<ChatListBloc>().add(ChatListReadItemEvent(c: m));
        },
        child: Row(
          mainAxisSize: MainAxisSize.max,
          crossAxisAlignment: CrossAxisAlignment.center,
          mainAxisAlignment: MainAxisAlignment.start,
          children: [
            Hero(
              tag: m.conversationId,
              child: WidgetAppImage(
                imageUrl: thumbnail,
                width: 26 * 2,
                height: 26 * 2,
                radius: 26 * 2,
                errorWidget: CircleAvatar(
                    backgroundImage: AssetImage(assetjpg('defaultavatar'),
                        package: '_private_core')),
              ),
            ),
            const SizedBox(
              width: 15,
            ),
            Flexible(
              fit: FlexFit.tight,
              child: Column(
                mainAxisAlignment: MainAxisAlignment.start,
                crossAxisAlignment: CrossAxisAlignment.start,
                mainAxisSize: MainAxisSize.min,
                children: [
                  Row(
                    children: [
                      Flexible(
                        fit: FlexFit.tight,
                        child: Text(
                          fullname,
                          maxLines: 1,
                          overflow: TextOverflow.ellipsis,
                          style: styleName,
                        ),
                      ),
                      const SizedBox(
                        height: 4,
                      ),
                      Text(
                        timeago.format(
                          DateTime.fromMillisecondsSinceEpoch(
                              m.lastMessage[DB_KEY_TIMESTAMP] ??
                                  m.data[DB_KEY_LAST_MESSAGE_TIME]),
                        ),
                        style: styleTime,
                      )
                    ],
                  ),
                  const SizedBox(
                    height: 6,
                  ),
                  Row(
                    children: [
                      Expanded(
                        child: !kIsWeb &&
                                appPrefs
                                    .getDraftMessage(m.conversationId)
                                    .trim()
                                    .isNotEmpty
                            ? Text(
                                'draft'.tr,
                                maxLines: 2,
                                overflow: TextOverflow.ellipsis,
                                style: styleMessage.copyWith(color: mainColor),
                              )
                            : Text(
                                msg,
                                maxLines: 2,
                                overflow: TextOverflow.ellipsis,
                                style: styleMessage,
                              ),
                      ),
                      if (unread > 0)
                        CircleAvatar(
                          backgroundColor: hexColor('#3E61F7'),
                          radius: 7,
                          child: Padding(
                            padding: const EdgeInsets.all(2.0),
                            child: FittedBox(
                              child: Text(
                                '$unread',
                                style: w700TextStyle()
                                    .copyWith(color: Colors.white),
                              ),
                            ),
                          ),
                        )
                    ],
                  )
                ],
              ),
            ),
          ],
        ),
      ),
    );
  }
}
